@@ -2,7 +2,8 @@
 import os
 import re
 import unittest
-from nexus import NexusReader
+from nexus.reader import NexusReader
+from nexus.handlers.data import DataHandler
 
 EXAMPLE_DIR = os.path.join(os.path.dirname(__file__), '../examples')
 REGRESSION_DIR = os.path.join(os.path.dirname(__file__), 'regression')
@@ -126,20 +127,22 @@ class Test_TaxaHandler_Regression_Mesquite(unittest.TestCase):
 
     def test_taxa_block_attributes(self):
         assert 'taxa' in self.nex.blocks
-        assert len(self.nex.taxa.attributes) == 1
+        assert len(self.nex.taxa.attributes) == 2
         assert 'TITLE Untitled_Block_of_Taxa;' in self.nex.taxa.attributes
-
+        assert 'LINK Taxa = Untitled_Block_of_Taxa;' in \
+            self.nex.taxa.attributes
+    
     def test_write(self):
         expected_patterns = [
-            '^begin taxa;$',
-            '^\s+TITLE Untitled_Block_of_Taxa;$',
-            '^\s+dimensions ntax=3;$',
-            '^\s+taxlabels$',
-            "^\s+\[1\] 'A'$",
-            "^\s+\[2\] 'B'$",
-            "^\s+\[3\] 'C'$",
-            '^;$',
-            '^end;$',
+            r'^begin taxa;$',
+            r'^\s+TITLE Untitled_Block_of_Taxa;$',
+            r'^\s+dimensions ntax=3;$',
+            r'^\s+taxlabels$',
+            r"^\s+\[1\] A$",
+            r"^\s+\[2\] B$",
+            r"^\s+\[3\] C$",
+            r'^;$',
+            r'^end;$',
         ]
         written = self.nex.write()
         for expected in expected_patterns:
@@ -156,7 +159,8 @@ class Test_DataHandler_Regression_Mesquite(unittest.TestCase):
         #NEXUS
 
         Begin data;
-        TITLE something;
+        TITLE Untitled_Block_of_Taxa;
+        LINK Taxa = Untitled_Block_of_Taxa;
         Dimensions ntax=2 nchar=2;
         Format datatype=standard gap=- symbols="01";
         Matrix
@@ -165,21 +169,26 @@ class Test_DataHandler_Regression_Mesquite(unittest.TestCase):
             ;
         End;
         """)
-
-    def test_attr_find(self):
-        assert len(self.nex.data.attributes) == 1
+    
+    def test_attributes(self):
+        assert len(self.nex.data.attributes) == 2
+        assert self.nex.data.attributes[0] == \
+            """TITLE Untitled_Block_of_Taxa;"""
+        assert self.nex.data.attributes[1] == \
+            """LINK Taxa = Untitled_Block_of_Taxa;"""
 
     def test_write(self):
         expected_patterns = [
-            '^begin data;$',
-            '^\s+TITLE something;$',
-            '^\s+dimensions ntax=2 nchar=2;$',
-            '^\s+format datatype=standard gap=- symbols="01";$',
-            "^matrix$",
-            "^Harry\s+00",
-            "^Simon\s+01$",
-            '^\s+;$',
-            '^end;$',
+            r'^begin data;$',
+            r'^\s+TITLE Untitled_Block_of_Taxa;$',
+            r'^\s+LINK Taxa = Untitled_Block_of_Taxa;$',
+            r'^\s+dimensions ntax=2 nchar=2;$',
+            r'^\s+format datatype=standard gap=- symbols="01";$',
+            r"^matrix$",
+            r"^Harry\s+00",
+            r"^Simon\s+01$",
+            r'^\s+;$',
+            r'^end;$',
         ]
         written = self.nex.write()
         for expected in expected_patterns:
@@ -222,3 +231,117 @@ class Test_TreeHandler_Regression_Mesquite(unittest.TestCase):
         written = self.nex.write()
         assert """Title 'Trees from "temp.trees"';""" in written
         assert """LINK Taxa = Untitled_Block_of_Taxa;""" in written
+
+
+
+class Test_TaxaHandler_OneLine(unittest.TestCase):
+    """
+    Regression: Test that we can read taxalabels delimited by spaces not new
+    lines.
+    """
+    def setUp(self):
+        self.nex = NexusReader(
+            os.path.join(REGRESSION_DIR, 'taxlabels.nex')
+        )
+    
+    def test_block_find(self):
+        assert 'taxa' in self.nex.blocks
+        assert 'data' in self.nex.blocks
+        
+    def test_taxa(self):
+        for taxon in ['A', 'B', 'C']:
+            assert taxon in self.nex.data.matrix
+            assert taxon in self.nex.blocks['taxa'].taxa
+        assert self.nex.blocks['taxa'].ntaxa == 3
+    
+    def test_charblock_find(self):
+        assert hasattr(self.nex.data, 'characters')
+
+    def test_data_ntaxa(self):
+        assert self.nex.data.ntaxa == 3
+
+    def test_data_nchar(self):
+        assert self.nex.data.nchar == 3
+
+    def test_matrix(self):
+        assert self.nex.data.matrix["A"] == ["1", "1", "1"]
+        assert self.nex.data.matrix["B"] == ["0", "1", "1"]
+        assert self.nex.data.matrix["C"] == ["0", "0", "1"]
+        
+
+class Test_GlottologTree(unittest.TestCase):
+    """
+    Regression: Test that we can read glottolog tree format.
+    """
+    def setUp(self):
+        self.nex = NexusReader(
+            os.path.join(REGRESSION_DIR, 'glottolog.trees')
+        )
+    
+    def test_block_find(self):
+        assert 'taxa' in self.nex.blocks
+        assert 'trees' in self.nex.blocks
+    
+    def test_taxa(self):
+        for i in range(2, 6):
+            taxon = 'abun125%d' % i
+            assert taxon in self.nex.blocks['taxa'].taxa
+    
+    def test_taxa_count(self):
+        # has duplicate taxon label
+        assert self.nex.blocks['taxa'].ntaxa == 4
+    
+    def test_tree_count(self):
+        assert len(self.nex.trees.trees) == 1
+    
+
+class Test_DataHandler_NoMissingInSymbols(unittest.TestCase): 
+    """
+    Regression:
+    Test that the missing or gap symbols are NOT in the SYMBOLS format string
+    """
+    def test_write(self):
+        self.nex = NexusReader()
+        self.nex.read_string("""
+        #NEXUS
+        begin data;
+        Dimensions ntax=2 nchar=2;
+        Format datatype=standard gap=- symbols="01";
+        Matrix
+        Harry              1-
+        Simon              0?
+            ;
+        End;
+        """)
+        expected_patterns = [
+            r'^begin data;$',
+            r'^\s+dimensions ntax=2 nchar=2;$',
+            r'^\s+format datatype=standard gap=- symbols="01";$',
+            r"^matrix$",
+            r"^Harry\s+1-",
+            r"^Simon\s+0\?$",
+            r'^\s+;$',
+            r'^end;$',
+        ]
+        written = self.nex.write()
+        for expected in expected_patterns:
+            assert re.search(expected, written, re.MULTILINE), \
+                'Expected "%s"' % expected
+    
+
+class Test_DataHandler_ParsingGlitch(unittest.TestCase):
+    """
+    Regression:
+    Fix for parsing glitch in DataHandler.parse_format()
+    """
+    def test_parse_format_line(self):
+        d = DataHandler()
+        f = d.parse_format_line('FORMAT DATATYPE=STANDARD GAP=- MISSING=? SYMBOLS = "012345";')
+        assert f['datatype'] == 'standard', \
+            "Expected 'standard', but got '%s'" % f['datatype']
+        assert f['symbols'] == '012345', \
+            "Expected '012345', but got '%s'" % f['symbols']
+        assert f['gap'] == '-', \
+            "Expected 'gap', but got '%s'" % f['gap']
+        assert f['missing'] == '?', \
+            "Expected 'gap', but got '%s'" % f['missing']
